#[repr(u8)]pub enum BnLogLevel {
DebugLog = 0,
InfoLog = 1,
WarningLog = 2,
ErrorLog = 3,
AlertLog = 4,
}Expand description
! Console log levels
Variants
DebugLog = 0
InfoLog = 1
! Debug logging level, most verbose logging level
WarningLog = 2
! Information logging level, default logging level
ErrorLog = 3
! Warning logging level, messages show with warning icon in the UI
AlertLog = 4
! Error logging level, messages show with error icon in the UI